@@ -33,7 +33,7 @@ class Demo():
         self.frame = frame = HtmlFrame(root)
 
         frame.on_title_change(self.change_title)
-        frame.load_website("http://tkhtml.tcl.tk")
+        frame.load_website("www.wikipedia.org")
 
         frame.pack(expand=True, fill="both")
         root.mainloop()
